@@ -88,7 +88,6 @@ void hts_lowcase(char *s);
 const char *hts_optalias[][4] = {
   /*   {"","","",""}, */
   {"path", "-O", "param1", "output path"},
-  {"chroot", "-%O", "param1", "default top path"},
   {"mirror", "-w", "single", ""},
   {"mirror-wizard", "-W", "single", ""},
   {"get-files", "-g", "single", ""},
@@ -102,7 +101,6 @@ const char *hts_optalias[][4] = {
   {"max-files", "-m", "param", ""},
   {"max-size", "-M", "param", ""},
   {"max-time", "-E", "param", ""},
-  {"max-mms-time", "-%m", "param", ""},
   {"max-rate", "-A", "param", ""},
   {"max-pause", "-G", "param", ""},
   {"sockets", "-c", "param", "number of simultaneous connections allowed"},
@@ -124,6 +122,8 @@ const char *hts_optalias[][4] = {
   {"list", "-%L", "param1", ""},
   {"urllist", "-%S", "param1", ""},
   {"language", "-%l", "param1", ""}, {"lang", "-%l", "param1", ""},
+  {"accept", "-%a", "param1", ""},
+  {"headers", "-%X", "param1", ""},
   {"structure", "-N", "param", ""}, {"user-structure", "-N", "param1", ""},
   {"long-names", "-L", "param", ""},
   {"keep-links", "-K", "param", ""},
@@ -210,7 +210,6 @@ const char *hts_optalias[][4] = {
   {"debug-xfrstats", "-#T", "single", ""},
   {"advanced-wait", "-#u", "single", ""},
   {"debug-ratestats", "-#Z", "single", ""},
-  {"exec", "-#!", "param1", ""},
   {"fast-engine", "-#X", "single", "Enable fast routines"},
   {"debug-overflows", "-#X0", "single", "Attempt to detect buffer overflows"},
   {"debug-cache", "-#C", "param1", "List files in the cache"},
@@ -256,10 +255,6 @@ const char *hts_optalias[][4] = {
   {"add", "", "param0", "add URLs"},
   /* */
 
-  /* Specific */
-  {"user", "-%U", "param1", "output path"},
-  /* */
-
   /* Internal */
   {"catchurl", "--catchurl", "single", "catch complex URL through proxy"},
   {"updatehttrack", "--updatehttrack", "single",
@@ -577,13 +572,11 @@ int optinclude_file(const char *name, int *argc, char **argv, char *x_argvblk,
 /* Get home directory, '.' if failed */
 /* example: /home/smith */
 char *hts_gethome(void) {
-#ifndef _WIN32_WCE
   char *home = getenv("HOME");
 
   if (home)
     return home;
   else
-#endif
     return ".";
 }
 
