@@ -67,10 +67,12 @@ extern "C" {
 #ifdef __GNUC__
 #define HTS_UNUSED __attribute__ ((unused))
 #define HTS_STATIC static __attribute__ ((unused))
+#define HTS_INLINE __inline__
 #define HTS_PRINTF_FUN(fmt, arg) __attribute__ ((format (printf, fmt, arg)))
 #else
 #define HTS_UNUSED
 #define HTS_STATIC static
+#define HTS_INLINE
 #define HTS_PRINTF_FUN(fmt, arg)
 #endif
 #endif
@@ -109,7 +111,6 @@ extern "C" {
   extern HTSEXT_API t_abortLog abortLog__;
 #define abortLog(a) abortLog__(a, __FILE__, __LINE__)
 #define _ ,
-#ifndef _WIN32_WCE
 #define abortLogFmt(a) do { \
   FILE* fp = fopen("CRASH.TXT", "wb"); \
   if (!fp) fp = fopen("/tmp/CRASH.TXT", "wb"); \
@@ -126,11 +127,6 @@ extern "C" {
     fclose(fp); \
   } \
 } while(0)
-#else
-#define abortLogFmt(a) do { \
-  XCEShowMessageA("HTTrack " HTTRACK_VERSIONID " closed at '" __FILE__ "', line %d\r\nReason:\r\n%s\r\n", __LINE__, a); \
-} while(0)
-#endif
 
 #define assertf(exp) do { \
   if (! ( exp ) ) { \
@@ -138,7 +134,6 @@ extern "C" {
     if (htsCallbackErr != NULL) { \
       htsCallbackErr("assert failed: " #exp, __FILE__ , __LINE__ ); \
     } \
-    assert(exp); \
     abort(); \
   } \
 } while(0)
