@@ -49,6 +49,40 @@ int hts_isStringAscii(const char *s, size_t size) {
   return 1;
 }
 
+#define IS_ALNUM(C) ( ((C) >= 'A' && (C) <= 'Z') || ((C) >= 'a' && (C) <= 'z') || ((C) >= '0' && (C) <= '9') )
+#define CHAR_LOWER(C) ( ((C) >= 'A' && (C) <= 'Z') ? ((C) + 'a' - 'A') : (C) )
+static int hts_equalsAlphanum(const char *a, const char *b) {
+  size_t i, j;
+  for(i = 0, j = 0;; i++, j++) {
+    /* Skip non-alnum */
+    for(; a[i] != '\0' && !IS_ALNUM(a[i]); i++) ;
+    for(; b[j] != '\0' && !IS_ALNUM(b[j]); j++) ;
+    /* Compare */
+    if (CHAR_LOWER(a[i]) != CHAR_LOWER(b[j])) {
+      break;
+    }
+    /* End of string ? (note: a[i] == b[j]) */
+    else if (a[i] == '\0') {
+      return 1;
+    }
+  }
+  return 0;
+}
+#undef IS_ALNUM
+#undef CHAR_LOWER
+
+/* Copy the memory region [s .. s + size - 1 ] as a \0-terminated string. */
+static char *hts_stringMemCopy(const char *s, size_t size) {
+  char *dest = malloc(size + 1);
+
+  if (dest != NULL) {
+    memcpy(dest, s, size);
+    dest[size] = '\0';
+    return dest;
+  }
+  return NULL;
+}
+
 #ifdef _WIN32
 
 typedef struct wincodepage_t wincodepage_t;
@@ -207,45 +241,17 @@ static const wincodepage_t codepages[] = {
 UINT hts_getCodepage(const char *name) {
   int id;
 
-#define IS_ALNUM(C) ( ((C) >= 'A' && (C) <= 'Z') || ((C) >= 'a' && (C) <= 'z') || ((C) >= '0' && (C) <= '9') )
-#define CHAR_LOWER(C) ( ((C) >= 'A' && (C) <= 'Z') ? ((C) + 'a' - 'A') : (C) )
   for(id = 0; codepages[id].name != NULL; id++) {
-    int i, j;
-
     /* Compare the two strings, lowercase and alphanum only (ISO88591 == iso-8859-1) */
-    const char *a = name, *b = codepages[id].name;
-
-    for(i = 0, j = 0;; i++, j++) {
-      /* Skip non-alnum */
-      for(; a[i] != '\0' && !IS_ALNUM(a[i]); i++) ;
-      for(; b[j] != '\0' && !IS_ALNUM(b[j]); j++) ;
-      /* Compare */
-      if (CHAR_LOWER(a[i]) != CHAR_LOWER(b[j])) {
-        break;
-      }
-      /* End of string ? (note: a[i] == b[j]) */
-      else if (a[i] == '\0') {
-        return codepages[id].codepage;
-      }
+    if (hts_equalsAlphanum(name, codepages[id].name)) {
+      return codepages[id].codepage;
     }
   }
-#undef IS_ALNUM
-#undef CHAR_LOWER
+
   /* Not found */
   return 0;
 }
 
-static char *strndup(const char *s, size_t size) {
-  char *dest = malloc(size + 1);
-
-  if (dest != NULL) {
-    memcpy(dest, s, size);
-    dest[size] = '\0';
-    return dest;
-  }
-  return NULL;
-}
-
 LPWSTR hts_convertStringToUCS2(const char *s, int size, UINT cp, int *pwsize) {
   /* Size in wide chars of the output */
   const int wsize = MultiByteToWideChar(cp, 0, (LPCSTR) s, size, NULL, 0);
@@ -302,11 +308,11 @@ char *hts_convertUCS2StringToUTF8(LPWSTR woutput, int wsize) {
 char *hts_convertStringCPToUTF8(const char *s, size_t size, UINT cp) {
   /* Empty string ? */
   if (size == 0) {
-    return strndup(s, size);
+    return hts_stringMemCopy(s, size);
   }
   /* Already UTF-8 ? */
   if (cp == CP_UTF8 || hts_isStringAscii(s, size)) {
-    return strndup(s, size);
+    return hts_stringMemCopy(s, size);
   }
   /* Other (valid) charset */
   else if (cp != 0) {
@@ -329,11 +335,11 @@ char *hts_convertStringCPToUTF8(const char *s, size_t size, UINT cp) {
 char *hts_convertStringCPFromUTF8(const char *s, size_t size, UINT cp) {
   /* Empty string ? */
   if (size == 0) {
-    return strndup(s, size);
+    return hts_stringMemCopy(s, size);
   }
   /* Already UTF-8 ? */
   if (cp == CP_UTF8 || hts_isStringAscii(s, size)) {
-    return strndup(s, size);
+    return hts_stringMemCopy(s, size);
   }
   /* Other (valid) charset */
   else if (cp != 0) {
@@ -372,18 +378,65 @@ char *hts_convertStringSystemToUTF8(const char *s, size_t size) {
 #else
 
 #include <errno.h>
-#include <iconv.h>
 
-static char *hts_convertStringToUTF8_(const char *s, size_t size,
+#if ( defined(HTS_USEICONV) && ( HTS_USEICONV == 0 ) )
+#define DISABLE_ICONV
+#endif
+
+#ifndef DISABLE_ICONV
+#include <iconv.h>
+#else
+#include "htscodepages.h"
+
+/* decode from a codepage to UTF-8 */
+static char* hts_codepageToUTF8(const char *codepage, const char *s) {
+  /* find the given codepage */
+  size_t i;
+  for(i = 0 ; table_mappings[i].name != NULL
+      && !hts_equalsAlphanum(table_mappings[i].name, codepage) ; i++) ;
+
+  /* found ; decode */
+  if (table_mappings[i].name != NULL) {
+    size_t j, k;
+    char *dest = NULL;
+    size_t capa = 0;
+#define MAX_UTF 8
+    for(j = 0, k = 0 ; s[j] != '\0' ; j++) {
+      const unsigned char c = (unsigned char) s[j];
+      const hts_UCS4 uc = table_mappings[i].table[c];
+      const size_t max = k + MAX_UTF;
+      if (capa < max) {
+        for(capa = 16 ; capa < max ; capa <<= 1) ;
+        dest = realloc(dest, capa);
+        if (dest == NULL) {
+          return NULL;
+        }
+      }
+      if (dest != NULL) {
+        const size_t len = hts_writeUTF8(uc, &dest[k], MAX_UTF);
+        k += len;
+        assert(k < capa);
+      }
+    }
+    dest[k] = '\0';
+    return dest;
+#undef MAX_UTF
+  }
+  return NULL;
+}
+#endif
+
+static char *hts_convertStringCharset(const char *s, size_t size,
                                       const char *to, const char *from) {
   /* Empty string ? */
   if (size == 0) {
     return strdup("");
   }
   /* Already on correct charset ? */
-  if (strcasecmp(from, to) == 0) {
-    return strndup(s, size);
+  if (hts_equalsAlphanum(from, to)) {
+    return hts_stringMemCopy(s, size);
   }
+#ifndef DISABLE_ICONV
   /* Find codepage */
   else {
     const iconv_t cp = iconv_open(to, from);
@@ -442,6 +495,12 @@ static char *hts_convertStringToUTF8_(const char *s, size_t size,
       return outbuf;
     }
   }
+#else
+  /* Limited codepage decoding support only. */
+  if (hts_isCharsetUTF8(to)) {
+    return hts_codepageToUTF8(from, s);
+  }
+#endif
 
   /* Error, charset not found! */
   return NULL;
@@ -454,11 +513,11 @@ char *hts_convertStringToUTF8(const char *s, size_t size, const char *charset) {
   }
   /* Already UTF-8 ? */
   if (hts_isCharsetUTF8(charset) || hts_isStringAscii(s, size)) {
-    return strndup(s, size);
+    return hts_stringMemCopy(s, size);
   }
   /* Find codepage */
   else {
-    return hts_convertStringToUTF8_(s, size, "utf-8", charset);
+    return hts_convertStringCharset(s, size, "utf-8", charset);
   }
 }
 
@@ -469,11 +528,11 @@ char *hts_convertStringFromUTF8(const char *s, size_t size, const char *charset)
   }
   /* Already UTF-8 ? */
   if (hts_isCharsetUTF8(charset) || hts_isStringAscii(s, size)) {
-    return strndup(s, size);
+    return hts_stringMemCopy(s, size);
   }
   /* Find codepage */
   else {
-    return hts_convertStringToUTF8_(s, size, charset, "utf-8");
+    return hts_convertStringCharset(s, size, charset, "utf-8");
   }
 }
 
@@ -1133,6 +1192,26 @@ hts_UCS4* hts_convertUTF8StringToUCS4(const char *s, size_t size, size_t *nChars
   return dest;
 }
 
+int hts_isStringUTF8(const char *s, size_t size) {
+  const unsigned char *const data = (const unsigned char*) s;
+  size_t i;
+
+  for(i = 0 ; i < size ; ) {
+    /* Reader: can read bytes up to j */
+#define RD ( i < size ? data[i++] : -1 )
+
+    /* Writer: upon error, return FFFD (replacement character) */
+#define WR(C) if ((C) == -1) { return 0; }
+
+    /* Read Unicode character. */
+    READ_UNICODE(RD, WR);
+#undef RD
+#undef WR
+  }
+
+  return 1;
+}
+
 char *hts_convertUCS4StringToUTF8(const hts_UCS4 *s, size_t nChars) {
   size_t i;
   char *dest = NULL;
