@@ -42,12 +42,8 @@ Please visit our Website: http://www.httrack.com
 #include <sys/types.h>
 #include <sys/stat.h>
 #ifdef _WIN32
-#ifndef  _WIN32_WCE
 #include <conio.h>
-#endif
-#ifndef  _WIN32_WCE
 #include <direct.h>
-#endif
 #else
 #ifndef _WIN32
 #include <unistd.h>
@@ -154,8 +150,6 @@ struct lien_url {
   char *cod;                    // chemin codebase éventuel si classe java
   char *former_adr;             // adresse initiale (avant éventuel moved), peut être nulle
   char *former_fil;             // nom du fichier distant initial (avant éventuel moved), peut être nul
-  // pour optimisation:
-  int hash_next[3];             // prochain lien avec même valeur hash
 };
 
 // chargement de fichiers en 'arrière plan'
@@ -260,9 +254,19 @@ struct cache_back {
 typedef struct hash_struct hash_struct;
 #endif
 struct hash_struct {
-  lien_url **liens;             // pointeur sur liens
-  int max_lien;                 // indice le plus grand rencontré
-  int hash[3][HTS_HASH_SIZE];   // tables pour sav/adr-fil/former_adr-former_fil
+  /* Links big array reference */
+  const lien_url **liens;
+  /* Savename (case insensitive ; lowercased) */
+  inthash sav;
+  /* Address and path */
+  inthash adrfil;
+  /* Former address and path */
+  inthash former_adrfil;
+  /** Buffers **/
+  int normalized;
+  char normfil[HTS_URLMAXSIZE * 2];
+  char normfil2[HTS_URLMAXSIZE * 2];
+  char catbuff[CATBUFF_SIZE];
 };
 
 #ifndef HTS_DEF_FWSTRUCT_filecreate_params
