@@ -1,12 +1,12 @@
 /* ------------------------------------------------------------ */
 /*
 HTTrack Website Copier, Offline Browser for Windows and Unix
-Copyright (C) Xavier Roche and other contributors
+Copyright (C) 1998-2013 Xavier Roche and other contributors
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 3
-of the License, or any later version.
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,8 +14,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 Important notes:
 
@@ -204,7 +203,8 @@ int hts_unescapeEntities(const char *src, char *dest, const size_t max) {
   return hts_unescapeEntitiesWithCharset(src, dest, max, "UTF-8");
 }
 
-int hts_unescapeUrl(const char *src, char *dest, const size_t max) {
+int hts_unescapeUrlSpecial(const char *src, char *dest, const size_t max,
+                           const int flags) {
   size_t i, j, lastI, lastJ, k, utfBufferJ, utfBufferSize;
   int seenQuery = 0;
   char utfBuffer[32];
@@ -239,7 +239,10 @@ int hts_unescapeUrl(const char *src, char *dest, const size_t max) {
         cUtf = (unsigned char) ec;
 
         /* Shortcut for ASCII (do not unescape non-printable) */
-        if ((unsigned char) ec < 0x80 && (unsigned char) ec >= 32) {
+        if (
+            (cUtf < 0x80 && cUtf >= 32)
+            && ( flags & UNESCAPE_URL_NO_ASCII ) == 0
+            ) {
           /* Rollback new write position and character */
           j = lastJ;
           c = ec;
@@ -251,7 +254,7 @@ int hts_unescapeUrl(const char *src, char *dest, const size_t max) {
     /* ASCII (and not in %xx) */
     else if (cUtf < 0x80 && i != lastI + 1) {
       k = 0;  /* cancel any sequence */
-      if (!seenQuery && c == '?') {
+      if (c == '?' && !seenQuery) {
         seenQuery = 1;
       }
     }
@@ -316,3 +319,7 @@ int hts_unescapeUrl(const char *src, char *dest, const size_t max) {
 
   return 0;
 }
+
+int hts_unescapeUrl(const char *src, char *dest, const size_t max) {
+  return hts_unescapeUrlSpecial(src, dest, max, 0);
+}
