@@ -36,24 +36,14 @@ Please visit our Website: http://www.httrack.com
 #define HTTRACK_GLOBAL_DEFH
 
 // Version (also check external version information)
-#define HTTRACK_VERSION      "3.47-27"
-#define HTTRACK_VERSIONID    "3.47.27"
+#define HTTRACK_VERSION      "3.48-1"
+#define HTTRACK_VERSIONID    "3.48.1"
 #define HTTRACK_AFF_VERSION  "3.x"
 #define HTTRACK_LIB_VERSION  "2.0"
 
 #ifndef HTS_NOINCLUDES
-#ifndef _WIN32_WCE
 #include <stdio.h>
 #include <stdlib.h>
-#else
-#include <stdio.h>
-#include <stdlib.h>
-#ifdef HTS_CECOMPAT
-#include "cecompat.h"
-#else
-#include "celib.h"
-#endif
-#endif
 #endif
 
 // Définition plate-forme
@@ -70,9 +60,6 @@ Please visit our Website: http://www.httrack.com
 // config.h
 #ifdef _WIN32
 
-// WIN32
-#ifndef _WIN32_WCE
-
 /*
 #define HAVE_SYS_STAT_H 1
 #define HAVE_SYS_TYPES_H 1
@@ -91,39 +78,6 @@ Please visit our Website: http://www.httrack.com
 
 #else
 
-// Win32CE
-//#pragma runtime_checks( "s", restore )
-#define HTS_SPARE_MEMORY 1
-#define HTS_ALIGN 8
-#define BIGSTK static
-#undef DLLIB                    // LoadLibrary(libssl) crashes
-#define NOSTRDEBUG 1
-#undef HTS_MAKE_KEYWORD_INDEX
-#ifdef HTS_CECOMPAT
-#define HTS_DO_NOT_USE_FTIME 1
-/*
-#undef HAVE_SYS_STAT_H
-#undef HAVE_SYS_TYPES_H
-*/
-#else
-#undef HTS_DO_NOT_USE_FTIME
-/*
-#define HAVE_SYS_STAT_H 1
-#define HAVE_SYS_TYPES_H 1
-*/
-#endif
-
-#define HTS_DLOPEN 0
-#undef HTS_INET6
-#ifndef S_ISREG
-#define S_ISREG(m) ((m) & _S_IFREG)
-
-#endif
-
-#endif
-
-#else
-
 #include "config.h"
 
 #ifndef FTIME
@@ -197,11 +151,6 @@ Please visit our Website: http://www.httrack.com
 #define HTS_USEOPENSSL 1
 #endif
 
-// utiliser mms://?
-#ifndef HTS_USEMMS
-#define HTS_USEMMS 1
-#endif
-
 #ifndef HTS_DLOPEN
 #define HTS_DLOPEN 1
 #endif
@@ -245,15 +194,11 @@ Please visit our Website: http://www.httrack.com
 #endif
 
 #if HTS_SPARE_MEMORY==0
-/* Gestion des tables de hashage */
-#define HTS_HASH_SIZE 20147
 /* Taille max d'une URL */
 #define HTS_URLMAXSIZE 1024
 /* Taille max ligne de commande (>=HTS_URLMAXSIZE*2) */
 #define HTS_CDLMAXSIZE 1024
 #else
-/* Gestion des tables de hashage */
-#define HTS_HASH_SIZE 1023
 /* Taille max d'une URL */
 #define HTS_URLMAXSIZE 256
 /* Taille max ligne de commande (>=HTS_URLMAXSIZE*2) */
@@ -282,8 +227,8 @@ Please visit our Website: http://www.httrack.com
 #define maximum(A,B) ( (A) > (B) ? (A) : (B) )
 #define minimum(A,B) ( (A) < (B) ? (A) : (B) )
 
-/* chaine vide? */
-#define strnotempty(A) (((A)[0]!='\0') ? 1 : 0)
+/* chaine no empty ? (and not null) */
+#define strnotempty(A) (((A) != NULL && (A)[0] != '\0'))
 
 /* optimisation inline si possible */
 #ifdef __cplusplus
@@ -326,9 +271,10 @@ typedef __int64 LLint;
 typedef __int64 TStamp;
 
 #define LLintP "%I64d"
-#elif (defined(__x86_64__) || defined(_LP64) || defined(__64BIT__))
-typedef unsigned long int LLint;
-typedef unsigned long int TStamp;
+#elif (defined(_LP64) || defined(__x86_64__) \
+       || defined(__powerpc64__) || defined(__64BIT__))
+typedef long int LLint;
+typedef long int TStamp;
 
 #define LLintP "%ld"
 #else
