@@ -485,10 +485,6 @@ void help(char *app, int more) {
   infomsg(" %cN maximum number of connections/seconds (*%c10)");
   infomsg
     ("  GN pause transfer if N bytes reached, and wait until lock file is deleted");
-#if HTS_USEMMS
-  infomsg
-    (" %mN maximum mms stream download time in seconds (60=1 minute, 3600=1 hour)");
-#endif
   infomsg("");
   infomsg("Flow control:");
   infomsg("  cN number of multiple connections (*c8)");
@@ -572,6 +568,8 @@ void help(char *app, int more) {
   infomsg
     (" %F  footer string in Html code (-%F \"Mirrored [from host %s [file %s [at %s]]]\"");
   infomsg(" %l  preffered language (-%l \"fr, en, jp, *\"");
+  infomsg(" %a  accepted formats (-%l \"text/html,image/png,image/jpeg,image/gif;q=0.9,*/*;q=0.1\"");
+  infomsg(" %X  additional HTTP header line (-%X \"X-Magic: 42\"");
   infomsg("");
   infomsg("Log, index, cache");
   infomsg
