@@ -119,14 +119,12 @@ int hts_primindex_words = 0;
 */
 void index_init(const char *indexpath) {
 #if HTS_MAKE_KEYWORD_INDEX
-#ifndef _WIN32_WCE
   /* remove(concat(indexpath,"index.txt")); */
   hts_index_init = 1;
   hts_primindex_size = 0;
   hts_primindex_words = 0;
   fp_tmpproject = tmpfile();
 #endif
-#endif
 }
 
 /* 
@@ -145,7 +143,7 @@ int index_keyword(const char *html_data, LLint size, const char *mime,
   int i = 0;
 
   //
-  int WordIndexSize = 1024;
+  //int WordIndexSize = 1024;
   inthash WordIndexHash = NULL;
   FILE *tmpfp = NULL;
 
@@ -174,11 +172,7 @@ int index_keyword(const char *html_data, LLint size, const char *mime,
   // FIXME - temporary fix for image/svg+xml (svg)
   // "IN XML" (html like, in fact :) )
   else if ((strfield2(mime, "image/svg+xml"))
-           || (strfield2(mime, "image/svg-xml"))
-#if HTS_USEMMS
-           || strfield2(mime, "video/x-ms-asf")
-#endif
-    ) {
+           || (strfield2(mime, "image/svg-xml"))) {
     inscript = 0;
   } else if ((strfield2(mime, "application/x-javascript"))
              || (strfield2(mime, "text/css"))
@@ -196,7 +190,7 @@ int index_keyword(const char *html_data, LLint size, const char *mime,
 
   // Create hash structure
   // Hash tables rulez da world!
-  WordIndexHash = inthash_new(WordIndexSize);
+  WordIndexHash = inthash_new(0);
   if (!WordIndexHash)
     return 0;
 
