@@ -101,9 +101,9 @@ typedef struct htsrequest_proxy htsrequest_proxy;
 #endif
 struct htsrequest_proxy {
   int active;
-  char name[1024];
+  const char* name;
   int port;
-  char bindhost[256];           // bind this host
+  const char* bindhost;           // bind this host
 };
 
 #ifndef HTS_DEF_FWSTRUCT_htsrequest
@@ -117,10 +117,12 @@ struct htsrequest {
   short int range_used;         // Range utilisé
   short int nocompression;      // Pas de compression
   short int flush_garbage;      // recycled
-  char user_agent[128];
-  char referer[256];
-  char from[256];
-  char lang_iso[64];
+  const char* user_agent;
+  const char* referer;
+  const char* from;
+  const char* lang_iso;
+  const char* accept;
+  const char* headers;
   htsrequest_proxy proxy;       // proxy
 };
 
@@ -161,7 +163,7 @@ struct htsblk {
   SSL *ssl_con;                 // connection structure
 #endif
   char lastmodified[64];        // Last-Modified
-  char etag[64];                // Etag
+  char etag[256];               // Etag
   char cdispo[256];             // Content-Disposition coupé
   LLint crange;                 // Content-Range
   LLint crange_start;           // Content-Range
@@ -229,6 +231,9 @@ struct t_dnscache {
 // initialize an htsblk structure
 void hts_init_htsblk(htsblk * r);
 
+// version
+HTSEXT_API const char* hts_version(void);
+
 // fonctions unix/winsock
 int hts_read(htsblk * r, char *buff, int size);
 
@@ -243,6 +248,7 @@ HTSEXT_API int hts_resetvar(void);      /* dummy */
 HTSEXT_API void hts_debug(int level);
 HTSEXT_API httrackp *hts_create_opt(void);
 HTSEXT_API void hts_free_opt(httrackp * opt);
+HTSEXT_API const hts_stat_struct* hts_get_stats(httrackp * opt);
 HTSEXT_API void set_wrappers(httrackp * opt);   /* LEGACY */
 HTSEXT_API int plug_wrapper(httrackp * opt, const char *moduleName,
                             const char *argv);
@@ -260,7 +266,6 @@ T_SOC http_xfopen(httrackp * opt, int mode, int treat, int waitconnect,
 int http_sendhead(httrackp * opt, t_cookie * cookie, int mode, char *xsend,
                   char *adr, char *fil, char *referer_adr, char *referer_fil,
                   htsblk * retour);
-htsblk httpget(httrackp * opt, char *url);
 
 //int newhttp(char* iadr,char* err=NULL);
 T_SOC newhttp(httrackp * opt, const char *iadr, htsblk * retour, int port,
@@ -273,8 +278,6 @@ htsblk http_location(httrackp * opt, char *adr, char *fil, char *loc);
 htsblk http_test(httrackp * opt, char *adr, char *fil, char *loc);
 int check_readinput(htsblk * r);
 int check_readinput_t(T_SOC soc, int timeout);
-void http_fread(T_SOC soc, htsblk * retour);
-LLint http_fread1(htsblk * r);
 void treathead(t_cookie * cookie, char *adr, char *fil, htsblk * retour,
                char *rcvd);
 void treatfirstline(htsblk * retour, char *rcvd);
@@ -284,8 +287,6 @@ HTSEXT_API void infostatuscode(char *msg, int statuscode);
 #endif
 
 // sous-fonctions
-htsblk xhttpget(httrackp * opt, char *adr, char *fil);
-htsblk http_gethead(httrackp * opt, char *adr, char *fil);
 LLint http_xfread1(htsblk * r, int bufl);
 HTS_INLINE t_hostent *hts_gethostbyname2(httrackp * opt, const char *iadr,
                                         void *v_buffer, const char **error);
@@ -294,12 +295,12 @@ HTS_INLINE t_hostent *hts_gethostbyname(httrackp * opt, const char *iadr,
 #ifndef HTTRACK_DEFLIB
 HTSEXT_API t_hostent *vxgethostbyname2(char *hostname, void *v_buffer, const char **error);
 HTSEXT_API t_hostent *vxgethostbyname(char *hostname, void *v_buffer);
+HTSEXT_API int check_hostname_dns(char *hostname);
 #endif
 int ftp_available(void);
 
 #if HTS_DNSCACHE
 void hts_cache_free(t_dnscache * cache);
-int hts_dnstest(httrackp * opt, const char *_iadr, int add);
 t_dnscache *_hts_cache(httrackp * opt);
 #endif
 
@@ -570,6 +571,7 @@ HTSEXT_API void hts_log_print(httrackp * opt, int type, const char *format,
   || (code) == 302               \
   || (code) == 303               \
   || (code) == 307               \
+  || (code) == 308               \
   )
 #define HTTP_IS_NOTMODIFIED(code) ( \
      (code) == 304               \
@@ -615,12 +617,6 @@ HTS_STATIC int strcmpnocase(char *a, char *b) {
 // is this MIME an hypertext MIME (text/html), html/js-style or other script/text type?
 #define HTS_HYPERTEXT_DEFAULT_MIME "text/html"
 
-#if HTS_USEMMS
-#define OPT_MMS(a) (strfield2((a), "video/x-ms-asf") != 0)
-#else
-#define OPT_MMS(a) (0)
-#endif
-
 #define is_html_mime_type(a) \
   ( (strfield2((a),"text/html")!=0)\
   || (strfield2((a),"application/xhtml+xml")!=0) \
@@ -641,7 +637,6 @@ HTS_STATIC int strcmpnocase(char *a, char *b) {
      (strfield2((a),"audio/x-pn-realaudio")!=0) \
      || (strfield2((a),"audio/x-mpegurl")!=0) \
      /*|| (strfield2((a),"text/xml")!=0) || (strfield2((a),"application/xml")!=0) : TODO: content check */ \
-     || OPT_MMS(a) \
   )
 
 /* Library internal definictions */
@@ -694,31 +689,6 @@ HTS_STATIC int compare_mime(httrackp * opt, const char *mime, const char *file,
 
 #endif
 
-#ifdef _WIN32_WCE_XXC
-extern char cwd[MAX_PATH + 1];
-HTS_STATIC char *getcwd_ce(char *buffer, int maxlen) {
-  TCHAR fileUnc[MAX_PATH + 1];
-  char *plast;
-
-  if (cwd[0] == 0) {
-    GetModuleFileName(NULL, fileUnc, MAX_PATH);
-    WideCharToMultiByte(CP_ACP, 0, fileUnc, -1, cwd, MAX_PATH, NULL, NULL);
-    plast = strrchr(cwd, '\\');
-    if (plast)
-      *plast = 0;
-    /* Special trick to keep start menu clean... */
-    if (_stricmp(cwd, "\\windows\\start menu") == 0)
-      strcpy(cwd, "\\Apps");
-  }
-  if (buffer)
-    strncpy(buffer, cwd, maxlen);
-  return cwd;
-}
-
-#undef getcwd
-#define getcwd getcwd_ce
-#endif
-
 /* dirent() compatibility */
 #ifdef _WIN32
 #define HTS_DIRENT_SIZE 256
