@@ -246,11 +246,22 @@ void htspe_init(void) {
 
     /* See CVE-2010-5252 */
 #if (defined(_WIN32) && (!defined(_DEBUG)))
-    /* See KB 2389418
-       "If this parameter is an empty string (""), the call removes the 
-       current directory from the default DLL search order" */
-    if (!SetDllDirectory("")) {
-      assertf(!"SetDllDirectory failed");
+    {
+      /* >= Windows Server 2003 (Andy Hewitt) */
+      const DWORD dwVersion = GetVersion();
+      const DWORD dwMajorVersion = (DWORD)(LOBYTE(LOWORD(dwVersion)));
+      const DWORD dwMinorVersion = (DWORD)(HIBYTE(LOWORD(dwVersion)));
+      const int hasSetDllDirectory =
+        dwMajorVersion >= 6 || ( dwMajorVersion == 5 && dwMinorVersion >= 2 );
+      /* See KB 2389418
+         "If this parameter is an empty string (""), the call removes the 
+         current directory from the default DLL search order" */
+      if (hasSetDllDirectory && !SetDllDirectory("")) {
+        /* Do no choke on NT or 98SE with KernelEx NT API (James Blough) */
+        if (dwMajorVersion >= 5) {
+          assertf(!"SetDllDirectory failed");
+        }
+      }
     }
 #endif
 
