@@ -146,10 +146,8 @@ int url_savename(char *adr_complete, char *fil_complete, char *save,
                  hash_struct * hash, int ptr, int numero_passe,
                  const lien_back * headers) {
   char catbuff[CATBUFF_SIZE];
-  const char *mime_type = (headers
-                           && !HTTP_IS_REDIRECT(headers->r.
-                                                statuscode)) ? headers->r.
-    contenttype : NULL;
+  const int is_redirect = headers != NULL && HTTP_IS_REDIRECT(headers->r.statuscode);
+  const char *mime_type = headers != NULL && !is_redirect ? headers->r.contenttype : NULL;
   /*const char* mime_type = ( headers && HTTP_IS_OK(headers->r.statuscode) ) ? headers->r.contenttype : NULL; */
   lien_back *const back = sback->lnk;
 
@@ -159,9 +157,9 @@ int url_savename(char *adr_complete, char *fil_complete, char *save,
   /*char BIGSTK normadr_[HTS_URLMAXSIZE*2]; */
   char BIGSTK normadr_[HTS_URLMAXSIZE * 2], normfil_[HTS_URLMAXSIZE * 2];
   enum { PROTOCOL_HTTP, PROTOCOL_HTTPS, PROTOCOL_FTP, PROTOCOL_FILE,
-      PROTOCOL_MMS, PROTOCOL_UNKNOWN };
+      PROTOCOL_UNKNOWN };
   static const char *protocol_str[] =
-    { "http", "https", "ftp", "file", "mms", "unknown" };
+    { "http", "https", "ftp", "file", "unknown" };
   int protocol = PROTOCOL_HTTP;
   const char *const adr = jump_identification(adr_complete);
   char *fil = fil_complete;
@@ -223,8 +221,6 @@ int url_savename(char *adr_complete, char *fil_complete, char *save,
     protocol = PROTOCOL_FTP;
   } else if (strfield(adr_complete, "file:")) {
     protocol = PROTOCOL_FILE;
-  } else if (strfield(adr_complete, "mms:")) {
-    protocol = PROTOCOL_MMS;
   } else {
     protocol = PROTOCOL_HTTP;
   }
@@ -266,12 +262,12 @@ int url_savename(char *adr_complete, char *fil_complete, char *save,
   if (liens != NULL) {
     int i;
 
-    i = hash_read(hash, normadr, normfil, 1, opt->urlhack);     // recherche table 1 (adr+fil)
+    i = hash_read(hash, normadr, normfil, HASH_STRUCT_ADR_PATH);     // recherche table 1 (adr+fil)
     if (i >= 0) {               // ok, trouvé
       strcpybuff(save, liens[i]->sav);
       return 0;
     }
-    i = hash_read(hash, normadr, normfil, 2, opt->urlhack);     // recherche table 2 (former_adr+former_fil)
+    i = hash_read(hash, normadr, normfil, HASH_STRUCT_ORIGINAL_ADR_PATH);     // recherche table 2 (former_adr+former_fil)
     if (i >= 0) {               // ok, trouvé
       // copier location moved!
       strcpybuff(adr_complete, liens[i]->adr);
@@ -290,7 +286,7 @@ int url_savename(char *adr_complete, char *fil_complete, char *save,
         fil_complete_patche[strlen(fil_complete_patche) - 1] = '\0';
       else
         strcatbuff(fil_complete_patche, "/");
-      i = hash_read(hash, normadr, fil_complete_patche, 2, opt->urlhack);       // recherche table 2 (former_adr+former_fil)
+      i = hash_read(hash, normadr, fil_complete_patche, HASH_STRUCT_ORIGINAL_ADR_PATH);       // recherche table 2 (former_adr+former_fil)
       if (i >= 0) {
         // écraser fil et adr (pas former_fil?????)
         strcpybuff(adr_complete, liens[i]->adr);
@@ -325,33 +321,6 @@ int url_savename(char *adr_complete, char *fil_complete, char *save,
       "could not URL-decode string '%s'", fil);
   }
 
-#if HTS_USEMMS
-  /* .asx hack */
-  if (headers != NULL && headers->r.cdispo[0] != 0
-      && strfield(headers->r.contenttype, "video/")
-      && strfield2(get_ext(OPT_GET_BUFF(opt), headers->r.cdispo), "asx") == 0) {
-    ext_chg = 1;
-    strcpybuff(ext, "asx");
-  } else if (headers != NULL && headers->r.contenttype[0] != 0
-             && strfield2(headers->r.contenttype, "video/x-ms-asf")) {
-    char *exts = get_ext(OPT_GET_BUFF(opt), headers->url_fil);
-
-    if (strfield2(exts, "wmv") == 0) {
-      ext_chg = 1;
-      strcpybuff(ext, "wmv");
-    } else if (strfield2(exts, "asf") == 0) {
-      ext_chg = 1;
-      strcpybuff(ext, "asf");
-    } else if (strfield2(exts, "avi") == 0) {
-      ext_chg = 1;
-      strcpybuff(ext, "avi");
-    } else if (strfield2(exts, "asx") == 0) {
-      ext_chg = 1;
-      strcpybuff(ext, "asx");
-    }
-  }
-#endif
-
   /* replace shtml to html.. */
   if (opt->savename_delayed == 2)
     is_html = -1;               /* ALWAYS delay type */
@@ -390,9 +359,6 @@ int url_savename(char *adr_complete, char *fil_complete, char *save,
 
     if (protocol != PROTOCOL_FILE
         && protocol != PROTOCOL_FTP
-#if HTS_USEMMS
-        && protocol != PROTOCOL_MMS
-#endif
       ) {
       // tester type avec requète HEAD si on ne connait pas le type du fichier
       if (!((opt->check_type == 1) && (fil[strlen(fil) - 1] == '/')))   // slash doit être html?
@@ -406,14 +372,16 @@ int url_savename(char *adr_complete, char *fil_complete, char *save,
             s[0] = '\0';
             hts_log_print(opt, LOG_DEBUG, "Testing link type (from cache) %s%s",
                           adr_complete, fil_complete);
-            if (strnotempty(r.cdispo)) {        /* filename given */
-              ext_chg = 2;      /* change filename */
-              strcpybuff(ext, r.cdispo);
-            } else if (!may_unknown2(opt, r.contenttype, fil)) {        // on peut patcher à priori?
-              give_mimext(s, r.contenttype);    // obtenir extension
-              if (strnotempty(s) > 0) { // on a reconnu l'extension
-                ext_chg = 1;
-                strcpybuff(ext, s);
+            if (!HTTP_IS_REDIRECT(r.statuscode)) {
+              if (strnotempty(r.cdispo)) {        /* filename given */
+                ext_chg = 2;      /* change filename */
+                strcpybuff(ext, r.cdispo);
+              } else if (!may_unknown2(opt, r.contenttype, fil)) {        // on peut patcher à priori?
+                give_mimext(s, r.contenttype);    // obtenir extension
+                if (strnotempty(s) > 0) { // on a reconnu l'extension
+                  ext_chg = 1;
+                  strcpybuff(ext, s);
+                }
               }
             }
 #ifdef DEFAULT_BIN_EXT
@@ -445,7 +413,7 @@ int url_savename(char *adr_complete, char *fil_complete, char *save,
           else if (opt->savename_delayed != 0 && !opt->state.stop) {
             // Check if the file is ready in backing. We basically take the same logic as later.
             // FIXME: we should cleanup and factorize this unholy mess
-            if (headers != NULL && headers->status >= 0) {
+            if (headers != NULL && headers->status >= 0 && !is_redirect) {
               if (strnotempty(headers->r.cdispo)) {        /* filename given */
                 ext_chg = 2;      /* change filename */
                 strcpybuff(ext, headers->r.cdispo);
@@ -602,9 +570,6 @@ int url_savename(char *adr_complete, char *fil_complete, char *save,
 
                               // ftp: stop!
                               if (strfield(mov_url, "ftp://")
-#if HTS_USEMMS
-                                  || strfield(mov_url, "mms://")
-#endif
                                 ) {     // ftp, ok on arrête
                                 has_been_moved = 1;
                                 back_maydelete(opt, cache, sback, b);   // ok
@@ -745,15 +710,8 @@ int url_savename(char *adr_complete, char *fil_complete, char *save,
   // Donner nom par défaut?
   if (fil[strlen(fil) - 1] == '/') {
     if (!strfield(adr_complete, "ftp://")
-#if HTS_USEMMS
-        && !strfield(adr_complete, "mms://")
-#endif
       ) {
       strcatbuff(fil, DEFAULT_HTML);    // nommer page par défaut!!
-#if HTS_USEMMS
-    } else if (strfield(adr_complete, "mms://")) {
-      strcatbuff(fil, DEFAULT_MMS);
-#endif
     } else {
       if (!opt->proxy.active)
         strcatbuff(fil, DEFAULT_FTP);   // nommer page par défaut (texte)
@@ -763,7 +721,7 @@ int url_savename(char *adr_complete, char *fil_complete, char *save,
   }
   // Changer extension?
   // par exemple, php3 sera sauvé en html, cgi en html ou gif, xbm etc.. selon les cas
-  if (ext_chg) {                // changer ext
+  if (ext_chg && !opt->no_type_change) {                // changer ext
     char *a = fil + strlen(fil) - 1;
 
     if ((opt->debug > 1) && (opt->log != NULL)) {
@@ -1007,6 +965,7 @@ int url_savename(char *adr_complete, char *fil_complete, char *save,
             /* release */
             RELEASE_ADR();
           }
+          b += strlen(b);       // pointer à la fin
           break;
         case 'H':              // host, raw (old mode)
           *b = '\0';
@@ -1570,7 +1529,7 @@ int url_savename(char *adr_complete, char *fil_complete, char *save,
       printf("\nStart search\n");
 #endif
 
-      i = hash_read(hash, save, "", 0, 0);      // lecture type 0 (sav)
+      i = hash_read(hash, save, NULL, HASH_STRUCT_FILENAME);      // lecture type 0 (sav)
       if (i >= 0) {
         int sameAdr = (strfield2(liens[i]->adr, normadr) != 0);
         int sameFil;
