@@ -153,7 +153,7 @@ static int hts_acceptlink_(httrackp * opt, int ptr, int lien_tot,
 
   /* Already exists? Then, we know that we knew that this link had to be known */
   if (adr[0] != '\0' && fil[0] != '\0' && opt->hash != NULL
-      && hash_read(opt->hash, adr, fil, 1, opt->urlhack) >= 0) {
+      && hash_read(opt->hash, adr, fil, 1) >= 0) {
     return 0;                   /* Yokai */
   }
   // -------------------- PRELUDE OF PHASE 3-BIS --------------------
@@ -842,11 +842,7 @@ static int hts_acceptlink_(httrackp * opt, int ptr, int lien_tot,
   if (just_test_it) {
     if (forbidden_url == 1) {
       if (opt->travel & 256) {  // tester tout de même
-        if (strfield(adr, "ftp://") == 0
-#if HTS_USEMMS
-            && strfield(adr, "mms://") == 0
-#endif
-          ) {                   // PAS ftp!
+        if (strfield(adr, "ftp://") == 0) {                   // PAS ftp!
           forbidden_url = 1;    // oui oui toujours interdit (note: sert à rien car ==1 mais c pour comprendre)
           *just_test_it = 1;    // mais on teste
           hts_log_print(opt, LOG_DEBUG, "Testing link %s%s", adr, fil);
