@@ -53,12 +53,14 @@ Please visit our Website: http://www.httrack.com
 /* Note: utf-8 */
 int hts_zunpack(char *filename, char *newfile) {
   int ret = -1;
-  char catbuff[CATBUFF_SIZE];
 
-  if (filename && newfile) {
+  if (filename != NULL && newfile != NULL) {
     if (filename[0] && newfile[0]) {
-      // not: NOT an UTF-8 filename
-      gzFile gz = gzopen(filename, "rb");
+      char catbuff[CATBUFF_SIZE];
+      FILE *const in = FOPEN(fconv(catbuff, filename), "rb");
+      const int fd = in != NULL ? fileno(in) : -1;
+      // Note: we must dup to be able to flose cleanly.
+      gzFile gz = fd != -1 ? gzdopen(dup(fd), "rb") : NULL;
 
       if (gz) {
         FILE *const fpout = FOPEN(fconv(catbuff, newfile), "wb");
@@ -70,7 +72,7 @@ int hts_zunpack(char *filename, char *newfile) {
           do {
             char BIGSTK buff[1024];
 
-            nr = gzread(gz, buff, 1024);
+            nr = gzread(gz, buff, sizeof(buff));
             if (nr > 0) {
               size += nr;
               if (fwrite(buff, 1, nr, fpout) != nr)
@@ -83,6 +85,9 @@ int hts_zunpack(char *filename, char *newfile) {
         gzclose(gz);
         ret = (int) size;
       }
+      if (in != NULL) {
+        fclose(in);
+      }
     }
   }
   return ret;
