@@ -165,7 +165,7 @@ void MD5Final(unsigned char digest[16], struct MD5Context *ctx) {
   if (ctx->doByteReverse)
     byteReverse((unsigned char *) ctx->buf, 4);
   memcpy(digest, ctx->buf, 16);
-  memset(ctx, 0, sizeof(ctx));  /* In case it's sensitive */
+  memset(ctx, 0, sizeof(*ctx));  /* In case it's sensitive */
 }
 
 /* The four core functions - F1 is optimized somewhat */
