@@ -40,7 +40,7 @@ woven in by Terry Thorsen 1/2003.
 #include <stdlib.h>
 #else
 #include <stdio.h>
-//#include "celib.h"
+#include "celib.h"
 #endif
 #include <string.h>
 
