@@ -1,12 +1,12 @@
 /* ------------------------------------------------------------ */
 /*
 HTTrack Website Copier, Offline Browser for Windows and Unix
-Copyright (C) Xavier Roche and other contributors
+Copyright (C) 1998-2013 Xavier Roche and other contributors
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 3
-of the License, or any later version.
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,8 +14,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 Please visit our Website: http://www.httrack.com
 */
@@ -91,12 +90,12 @@ int main(int argc, char *argv[]) {
   /* Args */
   printf("ProxyTrack %s, build proxies upon HTTrack Website Copier Archives\n",
          PROXYTRACK_VERSION);
-  printf("Copyright (C) Xavier Roche and other contributors\n");
+  printf("Copyright (C) 1998-2013 Xavier Roche and other contributors\n");
   printf("\n");
-  printf("This program is free software; you can redistribute it and/or\n");
-  printf("modify it under the terms of the GNU General Public License\n");
-  printf("as published by the Free Software Foundation; either version 3\n");
-  printf("of the License, or any later version.\n");
+  printf("This program is free software: you can redistribute it and/or modify\n");
+  printf("it under the terms of the GNU General Public License as published by\n");
+  printf("the Free Software Foundation, either version 3 of the License, or\n");
+  printf("(at your option) any later version.\n");
   printf("\n");
   printf("*** This version is a development release ***\n");
   printf("\n");
