@@ -30,6 +30,9 @@ Please visit our Website: http://www.httrack.com
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
+#ifdef __ANDROID__
+static long int  timezone = 0;
+#endif
 
 /* Locking */
 #ifdef _WIN32
@@ -233,7 +236,7 @@ struct _PT_Cache {
 PT_Indexes PT_New(void) {
   PT_Indexes index = (PT_Indexes) calloc(sizeof(_PT_Indexes), 1);
 
-  index->cil = inthash_new(127);
+  index->cil = inthash_new(0);
   index->index_size = 0;
   index->index = NULL;
   return index;
@@ -431,7 +434,7 @@ char **PT_Enumerate(PT_Indexes indexes, const char *url, int subtree) {
     inthash hdupes = NULL;
 
     if (!subtree)
-      hdupes = inthash_new(127);
+      hdupes = inthash_new(0);
     StringClear(list);
     StringClear(listindexes);
     StringClear(subitem);
@@ -548,7 +551,7 @@ PT_Index PT_LoadCache(const char *filename) {
       index->type = type;
       index->slots.common.timestamp = (time_t) time(NULL);
       index->slots.common.startUrl[0] = '\0';
-      index->slots.common.hash = inthash_new(8191);
+      index->slots.common.hash = inthash_new(0);
       if (!_IndexFuncts[type].PT_LoadCache(index, filename)) {
         proxytrack_print_log(DEBUG,
                              "reading httrack cache (format #%d) %s : error",
